@@ -8,19 +8,19 @@
  *           
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef _ATSPI_EVENT_LISTENER_H_
@@ -98,6 +98,13 @@ atspi_event_listener_register_full (AtspiEventListener *listener,
                                       GArray *properties,
 				      GError **error);
 
+gboolean
+atspi_event_listener_register_with_app (AtspiEventListener *listener,
+				        const gchar              *event_type,
+                                        GArray *properties,
+                                        AtspiAccessible *app,
+				        GError **error);
+
 gboolean
 atspi_event_listener_register_from_callback (AtspiEventListenerCB callback,
 				             void *user_data,
@@ -113,6 +120,15 @@ atspi_event_listener_register_from_callback_full (AtspiEventListenerCB callback,
                                                   GArray *properties,
 				                  GError **error);
 
+gboolean
+atspi_event_listener_register_from_callback_with_app (AtspiEventListenerCB callback,
+				                      void *user_data,
+				                      GDestroyNotify callback_destroyed,
+				                      const gchar              *event_type,
+                                                      GArray *properties,
+                                                      AtspiAccessible *app,
+				                      GError **error);
+
 gboolean
 atspi_event_listener_register_no_data (AtspiEventListenerSimpleCB callback,
 				 GDestroyNotify callback_destroyed,
